package com.dcsoft.system.face.mapper;

import java.util.List;
import com.dcsoft.system.face.domain.FaceImage;

/**
 * 图片信息Mapper接口
 *
 * @author nichun
 * @date 2023-03-30
 */
public interface FaceImageMapper
{
    /**
     * 查询图片信息
     *
     * @param id 图片信息主键
     * @return 图片信息
     */
    public FaceImage selectFaceImageById(Long id);

    /**
     * 查询图片信息列表
     *
     * @param faceImage 图片信息
     * @return 图片信息集合
     */
    public List<FaceImage> selectFaceImageList(FaceImage faceImage);

    /**
     * 新增图片信息
     *
     * @param faceImage 图片信息
     * @return 结果
     */
    public int insertFaceImage(FaceImage faceImage);

    /**
     * 修改图片信息
     *
     * @param faceImage 图片信息
     * @return 结果
     */
    public int updateFaceImage(FaceImage faceImage);

    /**
     * 删除图片信息
     *
     * @param id 图片信息主键
     * @return 结果
     */
    public int deleteFaceImageById(Long id);

    /**
     * 批量删除图片信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFaceImageByIds(Long[] ids);

    public int deleteFaceImageByStuIds(Long[] ids);

    public int deleteFaceImageByStuId(String id);

    public FaceImage selectFaceImageByStuId(String stuId);
}
